# kervi-devices
This is the device library for the Kervi automation framework.
It is included as a dependency when kervi is installed via pip.
For more information about kervi take a look at http://github.com/kervi/kervi
